@@ -56,9 +56,9 @@ class _ArjunFacade:
         self.__version = pkg_resources.require("arjuna")[0].version
 
     def launch(self, raw_args):
-        from arjuna.tpi.parser.text import TextResourceReader
+        from arjuna.tpi.parser.text import _TextResource
         from arjuna.interface.cli import ArjunaCLI
-        reader = TextResourceReader("header.txt")
+        reader = _TextResource("header.txt")
         print(reader.read().format(version=self.__version))
         reader.close()
 
@@ -80,6 +80,7 @@ from arjuna.tpi.tracker import track
 from arjuna.tpi.helper.arjtype import NVPair, NVPairs, Screen, Attr, Point, Offset, NetworkPacketInfo
 from arjuna.tpi.helper.audit import HardCoded
 from arjuna.tpi.helper.arjtype import ProcessedKeyDict
+from arjuna.tpi.helper.datetime import Time, DateTime, DateTimeDelta, DateTimeStepper
 
 from arjuna.tpi.parser.json import Json, JsonSchema
 from arjuna.tpi.parser.xml import Xml
