@@ -118,6 +118,8 @@ class CreateProject(Command):
         (FileObjectType.DIR, "data/reference/contextual"),
         (FileObjectType.DIR, "data/reference/indexed"),
         (FileObjectType.DIR, "data/file"),
+        (FileObjectType.DIR, "dbauto"),
+        (FileObjectType.DIR, "dbauto/sql"),
         (FileObjectType.DIR, "dependency"),
         (FileObjectType.DIR, "l10n"),
         (FileObjectType.DIR, "guiauto"),
@@ -187,7 +189,7 @@ class CreateProject(Command):
             f = open(get_proj_target_path("test/conftest.py"), "w")
             f.write(contents)
             f.close()
-            for d in ["data/source", "data/file", "data/reference/contextual", "data/reference/indexed", "dependency", "l10n", "guiauto/namespace", "tools/bmproxy"]:
+            for d in ["data/source", "data/file", "data/reference/contextual", "data/reference/indexed", "dbauto", "dbauto/sql", "dependency", "l10n", "guiauto/namespace", "tools/bmproxy"]:
                 copy_file("../../res/placeholder.txt", d + "/placeholder.txt")
             for os_name in ["mac", "windows", "linux"]:
                 copy_file("../../res/placeholder.txt", "guiauto/driver/{}/placeholder.txt".format(os_name))
@@ -220,13 +222,13 @@ class __RunCommand(Command):
         self.dry_run = arg_dict.pop("dry_run")
         if self.dry_run:
             self.dry_run = DryRunType[self.dry_run]
-        
+        self.linked_projects = arg_dict.pop("linked_projects")
         if "ref_conf" in arg_dict:
             self.ref_conf_name = arg_dict.pop("ref_conf")
 
         self.pop_command_args(arg_dict)
 
-        Arjuna.init(project_root_dir, CliArgsConfig(arg_dict), runid, static_rid=static_rid)
+        Arjuna.init(project_root_dir, CliArgsConfig(arg_dict), runid, static_rid=static_rid, linked_projects=self.linked_projects)
 
         import sys
         proj_dir = Arjuna.get_config().value(ArjunaOption.PROJECT_ROOT_DIR)
